@@ -1,6 +1,6 @@
 /// An intermediate type to abstract over various return types from subcommand
 /// functions.
-pub struct ExitCode(i32);
+pub struct ExitCode(std::process::ExitCode);
 
 pub trait IntoExitCode {
 	fn into_exit_code(self) -> ExitCode;
@@ -13,7 +13,7 @@ impl<T: std::process::Termination> IntoExitCode for T {
 }
 
 impl std::process::Termination for ExitCode {
-	fn report(self) -> i32 {
+	fn report(self) -> std::process::ExitCode {
 		self.0
 	}
 }
\ No newline at end of file
